==> augraphy-4.0.0-py3-none-any.whl: augraphy/augmentations/__init__.py <==
from augraphy.augmentations.badphotocopy import BadPhotoCopy
from augraphy.augmentations.bindingsandfasteners import BindingsAndFasteners
from augraphy.augmentations.bleedthrough import BleedThrough
from augraphy.augmentations.bookbinding import BookBinding
from augraphy.augmentations.brightness import Brightness
from augraphy.augmentations.brightnesstexturize import BrightnessTexturize
from augraphy.augmentations.dirtydrum import DirtyDrum
from augraphy.augmentations.dirtyrollers import DirtyRollers
from augraphy.augmentations.dithering import Dithering
from augraphy.augmentations.dustyink import DustyInk
from augraphy.augmentations.faxify import Faxify
from augraphy.augmentations.folding import Folding
from augraphy.augmentations.gamma import Gamma
from augraphy.augmentations.gaussianblur import GaussianBlur
from augraphy.augmentations.inkbleed import InkBleed
from augraphy.augmentations.jpeg import Jpeg
from augraphy.augmentations.letterpress import Letterpress
from augraphy.augmentations.lightinggradient import LightingGradient
from augraphy.augmentations.lowinkblobs import LowInkBlobs
from augraphy.augmentations.lowinkperiodiclines import LowInkPeriodicLines
from augraphy.augmentations.lowinkrandomlines import LowInkRandomLines
from augraphy.augmentations.noisetexturize import NoiseTexturize
from augraphy.augmentations.pageborder import PageBorder
from augraphy.augmentations.pencilscribbles import PencilScribbles
from augraphy.augmentations.scale import Scale
from augraphy.augmentations.strikethrough import Strikethrough
from augraphy.augmentations.subtlenoise import SubtleNoise


__all__ = [
    "BadPhotoCopy",
    "BindingsAndFasteners",
    "BleedThrough",
    "BookBinding",
    "Brightness",
    "BrightnessTexturize",
    "DirtyDrum",
    "DirtyRollers",
    "Dithering",
    "DustyInk",
    "Faxify",
    "Folding",
    "Gamma",
    "GaussianBlur",
    "InkBleed",
    "Jpeg",
    "Letterpress",
    "LightingGradient",
    "LowInkBlobs",
    "LowInkPeriodicLines",
    "LowInkRandomLines",
    "NoiseTexturize",
    "PageBorder",
    "PencilScribbles",
    "Scale",
    "Strikethrough",
    "SubtleNoise",
]

==> augraphy-7.0.0-py3-none-any.whl: augraphy/augmentations/__init__.py <==
from augraphy.augmentations.badphotocopy import BadPhotoCopy
from augraphy.augmentations.bindingsandfasteners import BindingsAndFasteners
from augraphy.augmentations.bleedthrough import BleedThrough
from augraphy.augmentations.bookbinding import BookBinding
from augraphy.augmentations.brightness import Brightness
from augraphy.augmentations.brightnesstexturize import BrightnessTexturize
from augraphy.augmentations.dirtydrum import DirtyDrum
from augraphy.augmentations.dirtyrollers import DirtyRollers
from augraphy.augmentations.dithering import Dithering
from augraphy.augmentations.faxify import Faxify
from augraphy.augmentations.folding import Folding
from augraphy.augmentations.gamma import Gamma
from augraphy.augmentations.geometric import Geometric
from augraphy.augmentations.inkbleed import InkBleed
from augraphy.augmentations.jpeg import Jpeg
from augraphy.augmentations.letterpress import Letterpress
from augraphy.augmentations.lightinggradient import LightingGradient
from augraphy.augmentations.lowinkperiodiclines import LowInkPeriodicLines
from augraphy.augmentations.lowinkrandomlines import LowInkRandomLines
from augraphy.augmentations.markup import Markup
from augraphy.augmentations.noisetexturize import NoiseTexturize
from augraphy.augmentations.pageborder import PageBorder
from augraphy.augmentations.pencilscribbles import PencilScribbles
from augraphy.augmentations.subtlenoise import SubtleNoise


__all__ = [
    "BadPhotoCopy",
    "BindingsAndFasteners",
    "BleedThrough",
    "BookBinding",
    "Brightness",
    "BrightnessTexturize",
    "DirtyDrum",
    "DirtyRollers",
    "Dithering",
    "Faxify",
    "Folding",
    "Gamma",
    "Geometric",
    "InkBleed",
    "Jpeg",
    "Letterpress",
    "LightingGradient",
    "LowInkPeriodicLines",
    "LowInkRandomLines",
    "Markup",
    "NoiseTexturize",
    "PageBorder",
    "PencilScribbles",
    "SubtleNoise",
]
